.. _spkg_overrides:

overrides: Decorator to automatically detect mismatch when overriding a method
========================================================================================

Description
-----------

Decorator to automatically detect mismatch when overriding a method

License
-------

Apache License, Version 2.0

Upstream Contact
----------------

https://pypi.org/project/overrides/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    7.4.0

version_requirements.txt::

    overrides


Equivalent System Packages
--------------------------

(none known)

